@@ -1,10 +1,8 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
+import json
 
 from ..error import TypeConversionError
 from ._interface import AbstractValueConverter
@@ -15,6 +13,14 @@ class DictionaryConverter(AbstractValueConverter):
         try:
             return dict(self._value)
         except (TypeError, ValueError):
-            raise TypeConversionError(
-                "failed to force_convert to dictionary: type={}".format(type(self._value))
-            )
+            pass
+
+        if isinstance(self._value, str):
+            try:
+                return json.loads(self._value)
+            except json.JSONDecodeError:
+                pass
+
+        raise TypeConversionError(
+            "failed to force_convert to dictionary: type={}".format(type(self._value))
+        )
