@@ -1,10 +1,8 @@
-# encoding: utf-8
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
 
-from __future__ import absolute_import, unicode_literals
+from typing import Any
 
 from .._typecode import Typecode
 from ..checker import IpAddressTypeChecker
@@ -23,11 +21,11 @@ class IpAddress(AbstractType):
     """
 
     @property
-    def typecode(self):
+    def typecode(self) -> Typecode:
         return Typecode.IP_ADDRESS
 
-    def __init__(self, value, strict_level=1, **kwargs):
-        super(IpAddress, self).__init__(value, strict_level, **kwargs)
+    def __init__(self, value: Any, strict_level: int = 1, **kwargs) -> None:
+        super().__init__(value, strict_level, **kwargs)
 
     def _create_type_checker(self):
         return IpAddressTypeChecker(self._data, self._strict_level)
